==> pyabaqus-1.0.3-py2.py3-none-any.whl: abaqus/CustomKernel/RegisteredDictionary.py <==
from .CommandRegister import CommandRegister


class RegisteredDictionary(CommandRegister):
    """This class allows you to create a dictionary that can be queried from the GUI and is
    capable of notifying the GUI when the contents of the dictionary change. The keys to a 
    RegisteredDictionary must be either strings or integers. 
    The RegisteredDictionary object is derived from the CommandRegister object. 

    Access
    ------
        - import customKernel

    Table Data
    ----------

    Corresponding analysis keywords
    -------------------------------

    """

    def __init__(self):
        """This method creates a RegisteredDictionary object.

        Path
        ----
            - customKernel.RegisteredDictionary

        Parameters
        ----------

        Returns
        -------
            A RegisteredDictionary object. 

        Exceptions
        ----------
            None. 
        """
        super().__init__()
        pass

    def Methods(self):
        """The RegisteredDictionary object supports the same methods as a Python dictionary. In
        addition, the RegisteredDictionary object supports the changeKey method.

        Parameters
        ----------

        Returns
        -------
            None. 

        Exceptions
        ----------
            None. 
        """
        pass

    def changeKey(self, fromName: str, toName: str):
        """This method changes the name of a key in the dictionary.

        Parameters
        ----------
        fromName
            A String or an integer specifying the name of the key to be changed. 
        toName
            A String or an integer specifying the new name for the key. 

        Returns
        -------
            None. 

        Exceptions
        ----------
            None. 
        """
        pass

==> pyabaqus-1.0.5-py2.py3-none-any.whl: abaqus/CustomKernel/RegisteredDictionary.py <==
from .CommandRegister import CommandRegister


class RegisteredDictionary(CommandRegister):
    """This class allows you to create a dictionary that can be queried from the GUI and is
    capable of notifying the GUI when the contents of the dictionary change. The keys to a 
    RegisteredDictionary must be either strings or integers. 
    The RegisteredDictionary object is derived from the CommandRegister object. 

    Access
    ------
        - import customKernel

    Table Data
    ----------

    Corresponding analysis keywords
    -------------------------------

    """

    def __init__(self):
        """This method creates a RegisteredDictionary object.

        Path
        ----
            - customKernel.RegisteredDictionary

        Parameters
        ----------

        Returns
        -------
            A RegisteredDictionary object. . 
        """
        super().__init__()
        pass

    def Methods(self):
        """The RegisteredDictionary object supports the same methods as a Python dictionary. In
        addition, the RegisteredDictionary object supports the changeKey method.

        Parameters
        ----------
        """
        pass

    def changeKey(self, fromName: str, toName: str):
        """This method changes the name of a key in the dictionary.

        Parameters
        ----------
        fromName
            A String or an integer specifying the name of the key to be changed. 
        toName
            A String or an integer specifying the new name for the key. 
        """
        pass
